@@ -344,19 +344,36 @@ restart_tabling(Closure, Wrapper, Worker) :-
 
 
 %!  start_subsumptive_tabling(:Wrapper, :Implementation)
+%
+%   (*) We should __not__ use  trie_gen_compiled/2   here  as  this will
+%   enumerate  all  answers  while  '$tbl_answer_update_dl'/2  uses  the
+%   available trie indexing to only fetch the relevant answer(s).
+%
+%   @tbd  In  the  end  '$tbl_answer_update_dl'/2  is  problematic  with
+%   incremental and shared tabling  as  we   do  not  get the consistent
+%   update view from the compiled result.
 
 start_subsumptive_tabling(Closure, Wrapper, Worker) :-
     (   '$tbl_existing_variant_table'(Closure, Wrapper, Trie, Status, Skeleton)
     ->  (   Status == complete
         ->  trie_gen_compiled(Trie, Skeleton)
         ;   Status == invalid
-        ->  reeval(Trie),
+        ->  reeval(Trie, Wrapper, Skeleton),
             trie_gen_compiled(Trie, Skeleton)
         ;   shift(call_info(Skeleton, Status))
         )
     ;   more_general_table(Wrapper, ATrie),
         '$tbl_table_status'(ATrie, complete, Wrapper, Skeleton)
-    ->  '$tbl_answer_update_dl'(ATrie, Skeleton)
+    ->  '$tbl_answer_update_dl'(ATrie, Skeleton) % see (*)
+    ;   more_general_table(Wrapper, ATrie),
+        '$tbl_table_status'(ATrie, Status, GenWrapper, GenSkeleton)
+    ->  (   Status == invalid
+        ->  reeval(ATrie, GenWrapper, GenSkeleton),
+            Wrapper = GenWrapper,
+            '$tbl_answer_update_dl'(ATrie, GenSkeleton)
+        ;   shift(call_info(GenSkeleton, Status)),
+            unify_subsumptive(Wrapper, GenWrapper)
+        )
     ;   '$tbl_variant_table'(Closure, Wrapper, Trie, _0Status, Skeleton),
         tdebug(_0Status == fresh),
         '$tbl_create_subcomponent'(SCC, Trie),
@@ -371,6 +388,7 @@ start_subsumptive_tabling(Closure, Wrapper, Worker) :-
         done_leader(LStatus, SCC, Skeleton, Clause)
     ).
 
+unify_subsumptive(X,X).
 
 :- '$hide'((done_leader/4, finished_leader/4)).
 
@@ -862,8 +880,9 @@ current_table(M:Variant, Trie) :-
     system:term_expansion/2.
 
 wrappers(Spec, M) -->
-    { tabling_defaults([ table_incremental-incremental,
-                         table_shared-tshared
+    { tabling_defaults([ table_incremental-(incremental=true),
+                         table_shared-(tshared=true),
+                         table_subsumptive-(mode=subsumptive)
                        ],
                        #{}, Defaults)
     },
@@ -946,9 +965,9 @@ qlist([H|T], M) --> [M:H], qlist(T, M).
 
 
 tabling_defaults([], Dict, Dict).
-tabling_defaults([Flag-Opt|T], Dict0, Dict) :-
+tabling_defaults([Flag-(Opt=Value)|T], Dict0, Dict) :-
     (   current_prolog_flag(Flag, true)
-    ->  Dict1 = Dict0.put(Opt,true)
+    ->  Dict1 = Dict0.put(Opt,Value)
     ;   Dict1 = Dict0
     ),
     tabling_defaults(T, Dict1, Dict).
