@@ -274,10 +274,8 @@ bookmarks_file(BM, Access:[{read,write}], File:name) :<-
     ->  get(F, absolute_path, File)
     ;   get(@pce, application_data, DataDir),
         (   Access == write
-        ->  (   send(DataDir, exists)
-            ->  true
-            ;   send(DataDir, make)
-            )
+        ->  get(DataDir, absolute_path, Path),
+            '$my_file'(Path)                % process owns path
         ;   true
         ),
         get(DataDir, file, emacs_bookmarks, F),
