@@ -496,11 +496,13 @@ trie_intern_indirect(trie *trie, word w, int add ARG_LD)
 { for(;;)
   { if ( trie->indirects )
     { return intern_indirect(trie->indirects, w, add PASS_LD);
-    } else
+    } else if ( add )
     { indirect_table *newtab = new_indirect_table();
 
       if ( !COMPARE_AND_SWAP(&trie->indirects, NULL, newtab) )
 	destroy_indirect_table(newtab);
+    } else
+    { return 0;
     }
   }
 }
@@ -1607,7 +1609,13 @@ static int
 get_key(trie_gen_state *state, descent_state *dstate, word *key ARG_LD)
 { Word p;
 
+  if ( dstate->size == 0 )
+  { *key = TRIE_KEY_POP(0);
+    return TRUE;
+  }
+
   deRef2(dstate->term, p);
+  DEBUG(CHK_SECURE, checkData(p));
 
   if ( canBind(*p) )
   { return FALSE;
@@ -1615,6 +1623,9 @@ get_key(trie_gen_state *state, descent_state *dstate, word *key ARG_LD)
   { Functor f = valueTerm(*p);
     desc_tstate dts;
 
+    DEBUG(MSG_TRIE_GEN,
+	  Sdprintf("get_key() for %s\n", functorName(f->definition)));
+
     *key = f->definition;
     if ( dstate->size > 1 )
     { if ( !dstate->compound )
@@ -1666,14 +1677,14 @@ add_choice(trie_gen_state *state, descent_state *dstate, trie_node *node ARG_LD)
   int has_key;
   word k;
 
-  DEBUG(MSG_TRIE_GEN,
-	{ Word p;
-	  deRef2(dstate->term, p);
-	  Sdprintf("add_choice() for %s\n", print_val(*p, NULL));
-	});
-
   if ( dstate->prune )
-  { if ( !(has_key = get_key(state, dstate, &k PASS_LD)) )
+  { DEBUG(MSG_TRIE_GEN,
+	  if ( dstate->size > 0 )
+	  { Word p;
+	    deRef2(dstate->term, p);
+	    Sdprintf("add_choice() for %s\n", print_val(*p, NULL));
+	  });
+    if ( !(has_key = get_key(state, dstate, &k PASS_LD)) )
       dstate->prune = FALSE;
   } else
     has_key = FALSE;
